==> scorched3d_38.1.orig.tar.gz: scorched3d-38.1/src/server/ServerBrowserInfo.h <==
////////////////////////////////////////////////////////////////////////////////
//    Scorched3D (c) 2000-2003
//
//    This file is part of Scorched3D.
//
//    Scorched3D is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    (at your option) any later version.
//
//    Scorched3D is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with Scorched3D; if not, write to the Free Software
//    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////////

#if !defined(__INCLUDE_ServerBrowserInfoh_INCLUDE__)
#define __INCLUDE_ServerBrowserInfoh_INCLUDE__

#include <SDL/SDL_net.h>

class ServerBrowserInfo
{
public:
	static ServerBrowserInfo *instance();

	bool start();
	void processMessages();

protected:
	static ServerBrowserInfo *instance_;
	UDPsocket udpsock_;
	UDPpacket **packetV_;

	void processMessage(UDPpacket *packet);
	void processStatusMessage(char *buffer);
	void processPlayerMessage(char *buffer);
	void processInfoMessage(char *buffer);
	void processPingMessage(char *buffer);
	void addTag(char *buffer, const char *name, const char *value);

private:
	ServerBrowserInfo();
	virtual ~ServerBrowserInfo();
};

#endif

==> scorched3d_41.3dfsg.orig.tar.gz: scorched3d-41.3dfsg/src/server/ServerBrowserInfo.h <==
////////////////////////////////////////////////////////////////////////////////
//    Scorched3D (c) 2000-2003
//
//    This file is part of Scorched3D.
//
//    Scorched3D is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    (at your option) any later version.
//
//    Scorched3D is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with Scorched3D; if not, write to the Free Software
//    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////////

#if !defined(__INCLUDE_ServerBrowserInfoh_INCLUDE__)
#define __INCLUDE_ServerBrowserInfoh_INCLUDE__

#include <net/NetBuffer.h>
#include <list>
#include <string>

class ServerBrowserInfo
{
public:
	static ServerBrowserInfo *instance();

	bool start();
	void processMessages();

protected:
	static ServerBrowserInfo *instance_;
	UDPsocket udpsock_;
	UDPpacket **packetV_;
	UDPpacket **packetVOut_;

	void processMessage(UDPpacket *packet);
	void processStatusMessage(std::list<std::string> &reply);
	void processPlayerMessage(std::list<std::string> &reply);
	void processInfoMessage(std::list<std::string> &reply);
	std::string addTag(const char *name, const char *value);

private:
	ServerBrowserInfo();
	virtual ~ServerBrowserInfo();
};

#endif
